chrome.runtime.onInstalled.addListener(() => {
    // When first installed, do the following.
    chrome.action.setBadgeText({
        // Can use badge text to store applciation state, if simple enough.
        text: "OFF"
    });
});

const extensions = 'https://developer.chrome.com/docs/extensions';
const webstore = 'https://developer.chrome.com/docs/webstore';

chrome.action.onClicked.addListener(async (tab) => {
    // When the extension is clicked, do the following.
    if (tab.url && (tab.url.startsWith(extensions) || tab.url.startsWith(webstore))) {
        // Retrieve the action badge to check if the extension is 'ON' or 'OFF'
        const prevState = await chrome.action.getBadgeText({ tabId: tab.id });
        // Next state will always be the opposite
        const nextState = prevState === 'ON' ? 'OFF' : 'ON'

        // Set the action badge to the next state
        await chrome.action.setBadgeText({
            tabId: tab.id,
            text: nextState,
        });

        if (nextState === "ON") {
            // Add a class to the current tab's body when the user turns the extension on.
            await chrome.scripting.executeScript({
                target: { tabId: tab.id! },
                func: () => {
                    document.body.classList.add('ext-focus-mode');
                }
            });
        } else if (nextState === "OFF") {
            // Remove a class from the current tab's body when the user turns the extension on.
            await chrome.scripting.executeScript({
                target: { tabId: tab.id! },
                func: () => {
                    document.body.classList.remove('ext-focus-mode');
                }
            });
        }
    }
});
